Learn R Programming

CRTspat (version 1.4.0)

CRTspat-package: CRTspat: Workflow for Cluster Randomised Trials with Spillover

Description

Design, workflow and statistical analysis of Cluster Randomised Trials of (health) interventions where there may be spillover between the arms (see https://thomasasmith.github.io/index.html).

Arguments

Author

Maintainer: Thomas Smith Thomas-a.Smith@unibas.ch (ORCID) [copyright holder]

Other contributors:

  • Lea Multerer [contributor]

  • Mariah Silkey [contributor]