summary.CRTsp: Summary description of a "CRTsp" object
Description
summary.CRTsp provides a description of a "CRTsp" object
Usage
# S3 method for CRTsp
summary(object, maskbuffer = 0.2, ...)
Value
No return value, write text to the console.
Arguments
object
an object of class "CRTsp" or a data frame containing locations in (x,y) coordinates, cluster
assignments (factor cluster), arm assignments (factor arm) and buffer zones (logical buffer),
together with any other variables required for subsequent analysis.
maskbuffer
radius of area around a location to include in calculation of areas